--[[============================================================================
gui.lua
============================================================================]]--

--Gui object definitions
DIALOG_MARGIN = renoise.ViewBuilder.DEFAULT_DIALOG_MARGIN
CONTENT_MARGIN = renoise.ViewBuilder.DEFAULT_CONTROL_MARGIN
CONTENT_SPACING = renoise.ViewBuilder.DEFAULT_CONTROL_SPACING
SECTION_MARGIN = 1
TOOL_FRAME_WIDTH = 472
CHECKBOX_WIDTH = 30
TEXT_ROW_WIDTH = 80
pa_gui = nil
tool_dialog = nil



function open_main_dialog()
  if tool_dialog ~= nil then
    if tool_dialog.visible then
      return
    end
  end
  change_from_config = true
    get_pitch_device_properties()
    get_midi_devices()
    get_instruments()
      if sample_transpose_mode == 1 then 
        pitch_range_max = 12
      else
        pitch_range_max = 120
      end    
  change_from_config = false
  --track_index = renoise.song().selected_track_index
  
  local vb = renoise.ViewBuilder()
  pa_gui = vb
--  print(selected_midi_device)
  if selected_midi_device > #device_list then
    selected_midi_device = 1
  end
  
  local main_frame = vb:column{
    id='main_frame',
    width=TOOL_FRAME_WIDTH,
    app_options(vb),
    
  }
   
  tool_dialog = renoise.app():show_custom_dialog("Pitch properties", 
  main_frame)
end



function app_options(vb)
  -------------------------------------------------------------------------
  -- Application options
  
  local layout_area=vb:column {
    width=428, 
    vb:row {
      vb:text {
        width=TEXT_ROW_WIDTH,
        text='Device'
      },
      vb:popup {
        id='selected_midi_device',
        width=200,
        items=device_list,
        value=selected_midi_device,
        tooltip="Select device for input or instrument control",
        notifier=function(value)
          selected_midi_device = value
          if not change_from_renoise then
            set_pitch_device_properties()
            monitor_pitch_bend_controller()
          end
        end
      },
      vb:space {width = 5,},
      vb:text {
        width=50,
        text='Channel'
      },
      vb:valuebox {
        id='selected_channel',
        width=50,
        min=0,
        max=16,
        value=selected_channel,
        tooltip='Midi channel to listen to',
        tostring = function(value) 

          if value == 0 then
            return "Any"
          else
            return tostring(value)
          end

        end,
        tonumber = function(str) 
          return tonumber(str)
        end,
        notifier=function(value) 
          selected_channel=value 
          if not change_from_renoise then
            set_pitch_device_properties()
          end
        end
      },
    },
    vb:row {
      vb:text {
        width=TEXT_ROW_WIDTH,
        text='Instrument link'
      },
      vb:popup {
        id='selected_instrument',
        width=200,
        items=instruments,
        value=selected_instrument,
        tooltip="Select device for input or instrument control",
        notifier=function(value)
          selected_instrument = value
          if not change_from_renoise then
            set_pitch_device_properties()
          end
        end
      },
    },
    vb:row {
      vb:text {
        width=50,
        text='Transpose link'
      },
      vb:space {width = 10,},
      vb:switch {
        id='sample_transpose_mode',
        width = 200,
        items={'pitch envelope','sample transpose'},
        tooltip = 'Which transpose option would you like to influence?\npitch envelope adds one point at the beginning'..
                  '\nsample transpose changes the semitone transpose value of the sample',
        value = sample_transpose_mode,
        notifier=function(value)
          sample_transpose_mode = value
          if sample_transpose_mode == 1 then
            instrument_links[renoise.song().selected_instrument_index] = false
            pitch_range_max = 12
          else
            instrument_links[renoise.song().selected_instrument_index] = true
            pitch_range_max = 120
          end
          if pa_gui ~= nil then 
            pa_gui.views['pitch_range'].max = pitch_range_max
          end
          
          link_sample_transpose(renoise.song().selected_instrument_index)          

          if not change_from_renoise then
            set_pitch_device_properties()
          end
        end
      },
      vb:space {width = 5,},
      vb:text {
        width=50,
        text='Pitch range'
      },
      vb:valuebox {
        id='pitch_range',
        width=50,
        min=1,
        max=pitch_range_max,
        value=pitch_range,
        tooltip='how many semitones to pitch?',
        notifier=function(value) 
          pitch_range=value 
          if not change_from_renoise then
            set_pitch_device_properties()
          end
        end
      },
      
    }
  }

  local property_area = vb:column{
    margin = CONTENT_MARGIN,
    spacing = CONTENT_SPACING,
    width = TOOL_FRAME_WIDTH+9,
    id='app_option_area',
    vb:horizontal_aligner {
      mode = "justify",
      width = "100%",
      margin=10,
      vb:column {
        vb:row{
          vb:column{
            margin = DIALOG_MARGIN,
            style = "group",

            vb:horizontal_aligner {
              mode = "center",
              layout_area
            }
          }
        }
      }
    }
  }  
  return property_area
  
end



--------------------------------------------------------------------------------
--      End of teh road...
--------------------------------------------------------------------------------

